View source: R/IPW_fnc_TatHgivenS.R
Provides wave period for a fixed wave steepness given wave height used for steepness curves on H/T plots
1 | IPW_fnc_TatHgivenS(Hs, Ss)
|
INPUT Hs - significant wave height Ss - required significant steepness
OUTPUT associated wave period to obtain required steepness
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.